### Info Box

An Info box is displayed below the current glyph.
The current glyph is the glyph currently being edited on, or, in text mode, the glyph following the text cursor.
The Info box shows general information about the glyph, including as its name, Unicode value, metrics, and kerning.

The glyph name is shown centered at the top of the Info box.
Its Unicode value, if any, is shown in the top-right of the box.

_UnicodeChecker_ is a Mac app by earthlingsoft.
Use it to explore and convert Unicode values.

Click the arrow  button next to the Unicode value to open it in UnicodeChecker.
If UnicodeChecker is not installed, Glyphs will present a download link.
When opening UnicodeChecker with the arrow button for the first time, the Mac will ask for permission.
Grant it so that Glyphs can launch UnicodeChecker and set the current Unicode value to match the one from Edit View.

#### Horizontal Layout

The lower half of the glyph Info box manages metrics and kerning.
To the left and right of the horizontal metrics  icon are left and right sidebearings.
Below the icon is the width of the glyph.
LSB, RSB, and width values can be numbers or metrics keys.
See Metrics Keys for more details.

Kerning values and kerning groups are at the left and right edge of the Info box.
See Kerning for more information.

#### Vertical Layout

For glyphs written in a vertical layout, the vertical Info box is displayed instead.

_{T} and _{B} are the top and bottom sidebearings of the glyph, respectively.
_{O} is the vertical origin of the glyph.

_{H} is the vertical width (or height) of the glyph.
_{K} and _{G} define the kerning and kerning groups, both for the top and the bottom of the glyph.